[![PyPI - Downloads](https://img.shields.io/pypi/dm/fsl-pipe-gui)](https://pypi.org/project/fsl-pipe-gui/)
[![Documentation](https://img.shields.io/badge/Documentation-fsl-pipe-gui-blue)](https://open.win.ox.ac.uk/pages/ndcn0236/fsl-pipe-gui)
[![Pipeline status](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/badges/main/pipeline.svg)](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/-/pipelines/latest)
[![Coverage report](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/badges/main/coverage.svg)](https://open.win.ox.ac.uk/pages/ndcn0236/fsl-pipe-gui/htmlcov)

terminal-based GUI for fsl-pipe

# Installation
```shell
pip install git+https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui.git
```

Any bug reports and feature requests are very welcome (see [issue tracker](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/-/issues)).

# Setting up local test environment
First clone the repository:
```shell
pip install https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui.git
```

Then, we install the package in an interactive manner:
```shell
cd fsl-pipe-gui
pip install -e .
```

Development tools can be installed using:
```
pip install -r requirements_dev.txt
pre-commit install  # installs pre-commit hooks to keep the code clean
```


## Running tests
Tests are run using the [pytest](https://docs.pytest.org) framework. They can be run from the project root as:
```shell
pytest src/tests
```

## Compiling documentation
The documentation is build using [sphinx](https://www.sphinx-doc.org/en/master/). After installation (`pip install sphinx`) run:
```shell
cd doc
sphinx-build source build
open build/index.html
```

## Contributing
[Merge requests](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/-/merge_requests) with any bug fixes or documentation updates are always welcome.

For new features, please raise an [issue](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/-/issues) to allow for discussion before you spend the time implementing them.

## Releasing new versions
- Run `bump2version` (install using `pip install bump2version`)
- Push to gitlab
- Manually activate the "to_pypi" task in the [pipeline](https://git.fmrib.ox.ac.uk/ndcn0236/fsl-pipe-gui/-/pipelines/latest) to upload to pypi
